@@ -1,4 +1,4 @@
-import os, sys, io, unittest, json, collections as cs
+import os, sys, io, unittest, json, enum, collections as cs
 
 import yaml
 
@@ -152,6 +152,10 @@ logging: # see http://docs.python.org/library/logging.config.html
     handlers: [console]
 '''
 
+class test_const(enum.IntEnum):
+	dispatch = 2455
+	heartbeat = 123
+
 data = dict(
 	path='/some/path',
 	query_dump=cs.OrderedDict([
@@ -160,7 +164,7 @@ data = dict(
 		('key3', 'тест3'),
 		('последний', None) ]),
 	ids=cs.OrderedDict(),
-	a=[1,None,'asd', 'не-ascii'], b=3.5, c=None,
+	a=[1,None,'asd', 'не-ascii'], b=3.5, c=None, d=test_const.dispatch,
 	asd=cs.OrderedDict([('b', 1), ('a', 2)]) )
 data['query_dump_clone'] = data['query_dump']
 data['ids']['id в уникоде'] = [4, 5, 6]
@@ -302,14 +306,28 @@ class DumpTests(unittest.TestCase):
 		pyaml.print(*args, file=buff)
 		self.assertEqual(b, buff.getvalue())
 
-	def test_str_style_pick(self):
+	def test_str_styles(self):
 		a = pyaml.dump(data_str_multiline)
 		b = pyaml.dump(data_str_multiline, string_val_style='|')
 		self.assertEqual(a, b)
 		b = pyaml.dump(data_str_multiline, string_val_style='plain')
 		self.assertNotEqual(a, b)
+		c = pyaml.dump(data_str_multiline, string_val_style='literal')
+		self.assertNotEqual(c, a)
+		self.assertNotEqual(c, b)
 		self.assertTrue(pyaml.dump('waka waka', string_val_style='|').startswith('|-\n'))
-		self.assertEqual(pyaml.dump(dict(a=1), string_val_style='|'), 'a: 1\n')
+
+		a = pyaml.dump(data_int := dict(a=123))
+		self.assertEqual(a, 'a: 123\n')
+		self.assertEqual(pyaml.dump(data_int, string_val_style='|'), a)
+		self.assertEqual(pyaml.dump(data_int, string_val_style='literal'), a)
+
+		a = pyaml.dump(data_str := dict(a='123'))
+		b = pyaml.dump(data_str, string_val_style='|')
+		self.assertEqual(a, "a: '123'\n")
+		self.assertEqual(self.flatten(data_str), self.flatten(yaml.safe_load(a)))
+		self.assertNotEqual(a, b)
+		self.assertEqual(self.flatten(data_str), self.flatten(yaml.safe_load(b)))
 
 	def test_colons_in_strings(self):
 		val1 = {'foo': ['bar:', 'baz', 'bar:bazzo', 'a: b'], 'foo:': 'yak:'}
@@ -369,6 +387,17 @@ class DumpTests(unittest.TestCase):
 		lines = pyaml.dump(d, sort_keys=False).splitlines()
 		self.assertEqual(lines, list(reversed(sorted(lines))))
 
+	def test_enum(self):
+		c = test_const.heartbeat
+		d1 = {'a': c, 'b': c.value, c: 'testx'}
+		self.assertEqual(d1['a'], d1['b'])
+		s = pyaml.dump(d1)
+		d2 = yaml.safe_load(s)
+		self.assertEqual(d1['a'], d2['a'])
+		self.assertEqual(d1['a'], c)
+		self.assertEqual(d1[c], 'testx')
+		self.assertIn('a: 123 # test_const.heartbeat', s)
+
 	def test_pyyaml_params(self):
 		d = {'foo': 'lorem ipsum ' * 30} # 300+ chars
 		for w in 40, 80, 200:
@@ -400,6 +429,27 @@ class DumpTests(unittest.TestCase):
 		data = YAML(typ='safe').load(large_yaml)
 		yaml_str = pyaml.dump(data)
 
+	def test_dump_stream_kws(self):
+		data = [1, 2, 3]
+		buff1, buff2 = io.StringIO(), io.StringIO()
+		pyaml.dump(data, dst=buff1)
+		pyaml.dump(data, stream=buff2)
+		self.assertEqual(buff1.getvalue(), buff2.getvalue())
+
+		buff1.seek(0); buff1.truncate()
+		pyaml.dump(data, dst=buff1, stream=buff1)
+		self.assertEqual(buff1.getvalue(), buff2.getvalue())
+		yaml = pyaml.dump(data, dst=str, stream=str)
+		self.assertEqual(yaml, buff2.getvalue())
+
+		buff1.seek(0); buff1.truncate(); buff2.seek(0); buff2.truncate()
+		with self.assertRaises(TypeError):
+			pyaml.dump(data, dst=buff1, stream=buff2)
+		with self.assertRaises(TypeError):
+			pyaml.dump(data, dst=str, stream=buff2)
+		self.assertEqual(buff1.getvalue(), '')
+		self.assertEqual(buff2.getvalue(), '')
+
 
 if __name__ == '__main__':
 	unittest.main()
